exceptiontools.MissingSpannerError
==================================

.. inheritance-diagram:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
